@@ -104,8 +104,7 @@ class DataType(EntityType):
 
         color_map.parent = self
         self._color_map = color_map
-        self.modified_attributes = "color_map"
-        self.workspace.finalize()
+        self.workspace.update_attribute(self, "color_map")
 
     @property
     def value_map(self) -> ReferenceValueMap | None:
@@ -141,7 +140,7 @@ class DataType(EntityType):
             value_map = ReferenceValueMap(value_map)
 
         self._value_map = value_map
-        self.modified_attributes = "Value map"
+        self.workspace.update_attribute(self, "Value map")
 
     @property
     def units(self) -> str | None:
@@ -153,7 +152,7 @@ class DataType(EntityType):
     @units.setter
     def units(self, unit: str):
         self._units = unit
-        self.modified_attributes = "attributes"
+        self.workspace.update_attribute(self, "attributes")
 
     @property
     def number_of_bins(self) -> int | None:
@@ -165,7 +164,7 @@ class DataType(EntityType):
     @number_of_bins.setter
     def number_of_bins(self, n_bins: int):
         self._number_of_bins = n_bins
-        self.modified_attributes = "attributes"
+        self.workspace.update_attribute(self, "attributes")
 
     @property
     def transparent_no_data(self) -> bool:
@@ -177,7 +176,7 @@ class DataType(EntityType):
     @transparent_no_data.setter
     def transparent_no_data(self, value: bool):
         self._transparent_no_data = value
-        self.modified_attributes = "attributes"
+        self.workspace.update_attribute(self, "attributes")
 
     @property
     def hidden(self) -> bool:
@@ -189,7 +188,7 @@ class DataType(EntityType):
     @hidden.setter
     def hidden(self, value: bool):
         self._hidden = value
-        self.modified_attributes = "attributes"
+        self.workspace.update_attribute(self, "attributes")
 
     @property
     def mapping(self) -> str:
@@ -206,7 +205,7 @@ class DataType(EntityType):
             value in mappings
         ), f"Mapping {value} was provided but should be one of {mappings}"
         self._mapping = value
-        self.modified_attributes = "attributes"
+        self.workspace.update_attribute(self, "attributes")
 
     @property
     def primitive_type(self) -> PrimitiveTypeEnum | None:
@@ -218,7 +217,9 @@ class DataType(EntityType):
     @primitive_type.setter
     def primitive_type(self, value):
         if isinstance(value, str):
-            self._primitive_type = getattr(PrimitiveTypeEnum, value.upper())
+            self._primitive_type = getattr(
+                PrimitiveTypeEnum, value.replace("-", "_").upper()
+            )
         else:
             assert isinstance(
                 value, PrimitiveTypeEnum
@@ -262,6 +263,7 @@ class DataType(EntityType):
         if entity_type is not None:
             return entity_type
 
+        kwargs["uid"] = uid
         return cls(workspace, **kwargs)
 
     @classmethod
