@@ -15,8 +15,10 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with geoh5py.  If not, see <https://www.gnu.org/licenses/>.
 
+from __future__ import annotations
 
-from .data import DataType, PrimitiveTypeEnum
+from ..shared import FLOAT_NDV
+from .data import PrimitiveTypeEnum
 from .numeric_data import NumericData
 
 
@@ -25,16 +27,13 @@ class FloatData(NumericData):
     Data container for floats values
     """
 
-    def __init__(self, data_type: DataType, **kwargs):
-        super().__init__(data_type, **kwargs)
-
     @classmethod
     def primitive_type(cls) -> PrimitiveTypeEnum:
         return PrimitiveTypeEnum.FLOAT
 
-    @classmethod
-    def ndv(cls) -> float:
+    @property
+    def ndv(self) -> float:
         """
         No-Data-Value
         """
-        return 1.17549435e-38
+        return FLOAT_NDV
