@@ -21,11 +21,11 @@ import uuid
 
 import numpy as np
 
+from .cell_object import CellObject
 from .object_base import ObjectType
-from .points import Points
 
 
-class Surface(Points):
+class Surface(CellObject):
     """
     Surface object defined by vertices and cells
     """
@@ -53,13 +53,24 @@ class Surface(Points):
         return self._cells
 
     @cells.setter
-    def cells(self, indices: np.ndarray):
+    def cells(self, indices: list | np.ndarray | None):
         if isinstance(indices, list):
             indices = np.vstack(indices)
 
-        assert np.issubdtype(
-            indices.dtype, np.integer
-        ), "Indices array must be of integer type"
+        if self._cells is not None and (
+            indices is None or indices.shape[0] < self._cells.shape[0]
+        ):
+            raise ValueError(
+                "Attempting to assign 'cells' with fewer values. "
+                "Use the `remove_cells` method instead."
+            )
+
+        if indices.ndim != 2 or indices.shape[1] != 3:
+            raise ValueError("Array of cells should be of shape (*, 3).")
+
+        if not np.issubdtype(indices.dtype, np.integer):
+            raise TypeError("Indices array must be of integer type")
+
         self._cells = indices.astype(np.int32)
         self.workspace.update_attribute(self, "cells")
 
