@@ -22,10 +22,9 @@ from typing import Any
 
 import numpy as np
 
-from geoh5py.data import FloatData
-from geoh5py.groups import PropertyGroup
-from geoh5py.objects import ObjectBase
-from geoh5py.objects.object_type import ObjectType
+from geoh5py.data.float_data import FloatData
+from geoh5py.groups.property_group import PropertyGroup
+from geoh5py.objects.object_base import ObjectBase
 
 
 class BaseEMSurvey(ObjectBase):
@@ -39,10 +38,6 @@ class BaseEMSurvey(ObjectBase):
     _receivers: BaseEMSurvey | None = None
     _transmitters: BaseEMSurvey | None = None
 
-    def __init__(self, object_type: ObjectType, **kwargs):
-
-        super().__init__(object_type, **kwargs)
-
     def add_components_data(self, data: dict) -> list[PropertyGroup]:
         """
         Add lists of data components to an EM survey. The name of each component is
@@ -101,7 +96,6 @@ class BaseEMSurvey(ObjectBase):
         for name, data_block in data.items():
             prop_group = self.add_validate_component_data(name, data_block)
             prop_groups.append(prop_group)
-        self.workspace.finalize()
 
         return prop_groups
 
@@ -109,7 +103,9 @@ class BaseEMSurvey(ObjectBase):
         """
         Append a property group to the entity and its metadata after validations.
         """
-        if name in [pg.name for pg in self.property_groups]:
+        if self.property_groups is not None and name in [
+            pg.name for pg in self.property_groups
+        ]:
             raise ValueError(
                 f"PropertyGroup named '{name}' already exists on the survey entity. "
                 f"Consider using the 'edit_metadata' method with "
@@ -214,9 +210,8 @@ class BaseEMSurvey(ObjectBase):
         )
         metadata["EM Dataset"][new_entity.type] = new_entity.uid
         for associate in ["transmitters", "receivers", "base_stations"]:
-            if (
-                getattr(self, associate, None) is not None
-                and getattr(self, associate) != self
+            if getattr(self, associate, None) is not None and not isinstance(
+                getattr(self, associate), type(self)
             ):
                 complement = parent.workspace.copy_to_parent(
                     getattr(self, associate),
@@ -229,7 +224,6 @@ class BaseEMSurvey(ObjectBase):
                 complement.metadata = self.metadata
 
         new_entity.metadata = metadata
-        parent.workspace.finalize()
 
         return new_entity
 
@@ -246,7 +240,6 @@ class BaseEMSurvey(ObjectBase):
     @classmethod
     def default_type_uid(cls) -> uuid.UUID:
         """Default unique identifier. Implemented on the child class."""
-        ...
 
     @property
     def default_transmitter_type(self) -> type:
@@ -294,8 +287,7 @@ class BaseEMSurvey(ObjectBase):
         if getattr(self, "base_stations", None) is not None:
             getattr(self, "base_stations").metadata = self.metadata
 
-        self.modified_attributes = "metadata"
-        self.workspace.finalize()
+        self.workspace.update_attribute(self, "metadata")
 
     def _edit_validate_property_groups(
         self, values: PropertyGroup | list[PropertyGroup] | None
@@ -319,7 +311,7 @@ class BaseEMSurvey(ObjectBase):
             values = [values]
 
         for value in values:
-            if value not in self.property_groups:
+            if self.property_groups is not None and value not in self.property_groups:
                 raise ValueError("Property group must be an existing PropertyGroup.")
 
             if len(value.properties) != len(self.channels):
@@ -352,7 +344,7 @@ class BaseEMSurvey(ObjectBase):
         self.edit_metadata({"Input type": value})
 
     @property
-    def metadata(self) -> dict:
+    def metadata(self):
         """Metadata attached to the entity."""
         if getattr(self, "_metadata", None) is None:
             metadata = self.workspace.fetch_metadata(self.uid)
@@ -393,7 +385,7 @@ class BaseEMSurvey(ObjectBase):
                     continue
 
         self._metadata = values
-        self.modified_attributes = "metadata"
+        self.workspace.update_attribute(self, "metadata")
 
     @property
     def receivers(self) -> BaseEMSurvey | None:
@@ -402,13 +394,13 @@ class BaseEMSurvey(ObjectBase):
         """
         if getattr(self, "_receivers", None) is None:
             if self.metadata is not None and "Receivers" in self.metadata["EM Dataset"]:
-                rx_uid = self.metadata["EM Dataset"]["Receivers"]
+                receiver = self.metadata["EM Dataset"]["Receivers"]
+                receiver_entity = self.workspace.get_entity(receiver)[0]
 
-                try:
-                    self._receivers = self.workspace.get_entity(rx_uid)[0]
-                except IndexError:
-                    print("Associated Receivers entity not found in Workspace.")
-                    return None
+                if isinstance(receiver_entity, BaseEMSurvey):
+                    self._receivers = receiver_entity
+                else:
+                    print("Associated receivers entity not found in Workspace.")
 
         return self._receivers
 
@@ -445,13 +437,13 @@ class BaseEMSurvey(ObjectBase):
                 self.metadata is not None
                 and "Transmitters" in self.metadata["EM Dataset"]
             ):
-                tx_uid = self.metadata["EM Dataset"]["Transmitters"]
+                transmitter = self.metadata["EM Dataset"]["Transmitters"]
+                transmitter_entity = self.workspace.get_entity(transmitter)[0]
 
-                try:
-                    self._transmitters = self.workspace.get_entity(tx_uid)[0]
-                except IndexError:
+                if isinstance(transmitter_entity, BaseEMSurvey):
+                    self._transmitters = transmitter_entity
+                else:
                     print("Associated transmitters entity not found in Workspace.")
-                    return None
 
         return self._transmitters
 
