@@ -304,7 +304,7 @@ def workspace2path(value):
 
 def path2workspace(value):
     if isinstance(value, str) and ".geoh5" in value:
-        return Workspace(value)
+        return Workspace(value, mode="r")
     return value
 
 
